@@ -89,9 +89,10 @@ class OpenMPGenerator(ProjectionGenerator, OpenMPConnectivity):
         # Detect delays to generate the code
         has_delay = proj.max_delay > 1
         if has_delay:
-            update_max_delay = self._update_max_delay(proj)
+            update_max_delay, reset_ring_buffer = self._update_max_delay(proj)
         else:
             update_max_delay = ""
+            reset_ring_buffer = ""
 
         # Connectivity matrix
         connectivity_matrix = self._connectivity(proj)
@@ -168,6 +169,7 @@ class OpenMPGenerator(ProjectionGenerator, OpenMPConnectivity):
             'update_prefix': update_prefix,
             'update_variables': update_variables,
             'update_max_delay': update_max_delay,
+            'reset_ring_buffer': reset_ring_buffer,
             'post_event_prefix': post_event_prefix,
             'post_event': post_event,
             'access_connectivity_matrix': connectivity_matrix['accessor'],
@@ -376,6 +378,9 @@ class OpenMPGenerator(ProjectionGenerator, OpenMPConnectivity):
             'delay_u' : '[delay-1]' # uniform delay
         }
 
+        # Dependencies
+        dependencies = list(set(proj.synapse_type.description['dependencies']['pre']))
+
         # Special keywords based on the data structure
         if proj._dense_matrix: # Dense connectivity
             ids['pre_index'] = '[j]'
@@ -399,11 +404,14 @@ class OpenMPGenerator(ProjectionGenerator, OpenMPConnectivity):
                 ' ' + psp
             )
 
+        # Allow the use of global variables in psp (issue60)
+        for var in dependencies:
+            if var in proj.pre.neuron_type.description['global']:
+                psp = psp.replace("%(pre_prefix)s"+var+"%(pre_index)s", "%(pre_prefix)s"+var+"%(global_index)s")
+
         # OpenMP
         with_openmp = Global.config['num_threads'] > 1 and proj.post.size > Global.OMP_MIN_NB_NEURONS
 
-        # Dependencies
-        dependencies = list(set(proj.synapse_type.description['dependencies']['pre']))
 
         # Delayed variables
         if isinstance(proj.pre, PopulationView):
@@ -434,7 +442,7 @@ class OpenMPGenerator(ProjectionGenerator, OpenMPConnectivity):
                         )
                     else:
                         psp = psp.replace(
-                            '%(pre_prefix)s'+var+'%(pre_index)s',
+                            '%(pre_prefix)s'+var+'%(global_index)s',
                             '%(pre_prefix)s_delayed_'+var+'%(delay_u)s'
                         )
 
@@ -1308,10 +1316,10 @@ if(_transmission && pop%(id_post)s._active){
         "When the maximum delay of a non-uniform spiking projection changes, the ring buffer for delyed spikes must be updated."
 
         if proj.synapse_type.type == 'rate':
-            return ""
+            return "", ""
 
         if proj.uniform_delay >= 0:
-            return ""
+            return "", ""
 
         update_delay_code = """
         // No need to do anything if the new max delay is smaller than the old one
@@ -1337,4 +1345,6 @@ if(_transmission && pop%(id_post)s._active){
         //     std::cout << _delayed_spikes[i][0].size() << std::endl;
 """
 
-        return update_delay_code
+        reset_ring_buffer_code = self._templates['delay']['nonuniform']['reset'] % {'id_pre': proj.pre.id}
+
+        return update_delay_code, reset_ring_buffer_code
