@@ -348,6 +348,7 @@ class Equation(object):
 
         # Standardize the equation
         real_tau, stepsize, steadystate = self.standardize_ODE(expression)
+
         if real_tau is None: # the equation can not be standardized
             return self.explicit(expression)
 
@@ -402,7 +403,7 @@ class Equation(object):
         variable_name = self.c_code(self.local_dict[self.name])
         steady = self.c_code(steadystate)
         if steady == '0':
-            code = variable_name + '*= exp(dt*(_last_event%(local_index)s - (t))/(' + self.c_code(real_tau) + '));'
+            code = variable_name + ' *= exp(dt*(_last_event%(local_index)s - (t))/(' + self.c_code(real_tau) + '));'
         else:
             code = variable_name + ' = ' + steady + ' + (' + variable_name + ' - ' + steady + ')*exp(dt*(_last_event%(local_index)s - (t))/(' + self.c_code(real_tau) + '));'
         return code
@@ -442,15 +443,17 @@ class Equation(object):
 
         # Make sure the expansion went well
         collected_var = sp.collect(expanded, self.local_dict[self.name], evaluate=False, exact=False)
-        if self.method == 'exponential':
+
+        if not self.local_dict[self.name] in collected_var.keys() or len(collected_var)>2:
+            collected_var = sp.collect(sp.simplify(expanded), self.local_dict[self.name], evaluate=False, exact=False)
             if not self.local_dict[self.name] in collected_var.keys() or len(collected_var)>2:
                 Global._print(self.expression)
-                Global._error('The exponential method is reserved for linear first-order ODEs of the type tau*d'+ self.name+'/dt + '+self.name+' = f(t). Use the explicit method instead.')
-
+                print(collected_var)
+                Global._error('The exponential and event-driven methods are reserved for linear first-order ODEs of the type tau*d'+ self.name+'/dt + '+self.name+' = f(t). Use the explicit method instead.')
 
         factor_var = collected_var[self.local_dict[self.name]]
 
-        collected_gradient = sp.collect(sp.expand(analysed, grad_var), grad_var, evaluate=False, exact=True)
+        collected_gradient = sp.collect(sp.expand(analysed, grad_var), grad_var, evaluate=False, exact=False)
         if grad_var in collected_gradient.keys():
             factor_gradient = collected_gradient[grad_var]
         else:
@@ -463,10 +466,10 @@ class Equation(object):
         normalized = analysed / factor_var
 
         # Steady state A
-        steadystate = sp.together(real_tau * grad_var + self.local_dict[self.name] - normalized)
+        steadystate = sp.simplify(sp.together(real_tau * grad_var + self.local_dict[self.name] - normalized))
 
         # Stepsize
-        stepsize = sp.together(self.local_dict['dt']/real_tau)
+        stepsize = sp.simplify(sp.together(self.local_dict['dt']/real_tau))
 
         return real_tau, stepsize, steadystate
 
